==> chaosmesh-model-5.2.0-sources.jar: annotations/io/fabric8/chaosmesh/v1alpha1/DNSChaosFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface DNSChaosFluent<A extends DNSChaosFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public DNSChaosFluent.MetadataNested<A> withNewMetadata();
    public DNSChaosFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public DNSChaosFluent.MetadataNested<A> editMetadata();
    public DNSChaosFluent.MetadataNested<A> editOrNewMetadata();
    public DNSChaosFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public DNSChaosSpec getSpec();
    public DNSChaosSpec buildSpec();
    public A withSpec(DNSChaosSpec spec);
    public Boolean hasSpec();
    public DNSChaosFluent.SpecNested<A> withNewSpec();
    public DNSChaosFluent.SpecNested<A> withNewSpecLike(DNSChaosSpec item);
    public DNSChaosFluent.SpecNested<A> editSpec();
    public DNSChaosFluent.SpecNested<A> editOrNewSpec();
    public DNSChaosFluent.SpecNested<A> editOrNewSpecLike(DNSChaosSpec item);
    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public DNSChaosStatus getStatus();
    public DNSChaosStatus buildStatus();
    public A withStatus(DNSChaosStatus status);
    public Boolean hasStatus();
    public DNSChaosFluent.StatusNested<A> withNewStatus();
    public DNSChaosFluent.StatusNested<A> withNewStatusLike(DNSChaosStatus item);
    public DNSChaosFluent.StatusNested<A> editStatus();
    public DNSChaosFluent.StatusNested<A> editOrNewStatus();
    public DNSChaosFluent.StatusNested<A> editOrNewStatusLike(DNSChaosStatus item);
    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<DNSChaosFluent.MetadataNested<N>> {

            public N and();
            public N endMetadata();    }


    public interface SpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DNSChaosSpecFluent<DNSChaosFluent.SpecNested<N>> {

            public N and();
            public N endSpec();    }


    public interface StatusNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DNSChaosStatusFluent<DNSChaosFluent.StatusNested<N>> {

            public N and();
            public N endStatus();    }


}

==> chaosmesh-model-5.3.0-sources.jar: annotations/io/fabric8/chaosmesh/v1alpha1/DNSChaosFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface DNSChaosFluent<A extends DNSChaosFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(int[] arg1,int arg2,int arg3);
    public A withNewApiVersion(char[] arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A withNewApiVersion(byte[] arg1,int arg2);
    public A withNewApiVersion(byte[] arg1);
    public A withNewApiVersion(char[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewApiVersion(String arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(int[] arg1,int arg2,int arg3);
    public A withNewKind(char[] arg1);
    public A withNewKind(StringBuffer arg1);
    public A withNewKind(byte[] arg1,int arg2);
    public A withNewKind(byte[] arg1);
    public A withNewKind(char[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKind(String arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public DNSChaosFluent.MetadataNested<A> withNewMetadata();
    public DNSChaosFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public DNSChaosFluent.MetadataNested<A> editMetadata();
    public DNSChaosFluent.MetadataNested<A> editOrNewMetadata();
    public DNSChaosFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public DNSChaosSpec getSpec();
    public DNSChaosSpec buildSpec();
    public A withSpec(DNSChaosSpec spec);
    public Boolean hasSpec();
    public DNSChaosFluent.SpecNested<A> withNewSpec();
    public DNSChaosFluent.SpecNested<A> withNewSpecLike(DNSChaosSpec item);
    public DNSChaosFluent.SpecNested<A> editSpec();
    public DNSChaosFluent.SpecNested<A> editOrNewSpec();
    public DNSChaosFluent.SpecNested<A> editOrNewSpecLike(DNSChaosSpec item);
    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public DNSChaosStatus getStatus();
    public DNSChaosStatus buildStatus();
    public A withStatus(DNSChaosStatus status);
    public Boolean hasStatus();
    public DNSChaosFluent.StatusNested<A> withNewStatus();
    public DNSChaosFluent.StatusNested<A> withNewStatusLike(DNSChaosStatus item);
    public DNSChaosFluent.StatusNested<A> editStatus();
    public DNSChaosFluent.StatusNested<A> editOrNewStatus();
    public DNSChaosFluent.StatusNested<A> editOrNewStatusLike(DNSChaosStatus item);
    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<DNSChaosFluent.MetadataNested<N>> {

            public N and();
            public N endMetadata();    }


    public interface SpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DNSChaosSpecFluent<DNSChaosFluent.SpecNested<N>> {

            public N and();
            public N endSpec();    }


    public interface StatusNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DNSChaosStatusFluent<DNSChaosFluent.StatusNested<N>> {

            public N and();
            public N endStatus();    }


}
